'use strict';

const Controller = require('../core/base_controller');

function toInt(str) {
  if (typeof str === 'number') return str;
  if (!str) return str;
  return parseInt(str, 10) || 0;
}

class OrgController extends Controller {
  async index() {
    const ctx = this.ctx;
    const query = {
      limit: toInt(ctx.query.limit),
      offset: toInt(ctx.query.offset),
    };
    const result = await ctx.model.Org.findAll(query);
    this.success(result);
  }

  async show() {
    const ctx = this.ctx;
    const result = await ctx.model.Org.findByPk(toInt(ctx.params.id));
    this.success(result);
  }

  async create() {
    const ctx = this.ctx;
    console.log(ctx.request.body);
    if (!ctx.request.body.org_name) {
      this.fail('请完善必填项！');
      return;
    }
    const org = await ctx.model.Org.create(ctx.request.body);
    await ctx.service.user.update(
      {
        role_type: ctx.request.body?.org_join_key,
        org_id: org.id,
      },
      this
    );
    this.success(org);
  }

  async update() {
    const ctx = this.ctx;
    const id = toInt(ctx.params.id);
    const org = await ctx.model.Org.findByPk(id);
    if (!org) {
      ctx.status = 404;
      ctx.body = {
        code: 1,
        success: false,
        msg: '库里没有该条数据',
      };
      return;
    }
    await org.update(ctx.request.body);
    this.success(org);
  }

  async destroy() {
    const ctx = this.ctx;
    const id = toInt(ctx.params.id);
    const org = await ctx.model.Org.findByPk(id);
    if (!org) {
      ctx.status = 404;
      ctx.body = {
        code: 1,
        success: false,
        msg: '库里没有该条数据',
      };
      return;
    }

    await org.destroy();
    this.success({
      data: '已删除',
    });
  }
}

module.exports = OrgController;
