'use strict';

const Controller = require('../core/base_controller');

function toInt(str) {
  if (typeof str === 'number') return str;
  if (!str) return str;
  return parseInt(str, 10) || 0;
}

class TagController extends Controller {
  async mutitag() {
    const ctx = this.ctx;
    const updates = await ctx.service.tag.mutiupdate(
      ctx.request.body?.tags ?? []
    );
    this.success(updates);
  }

  async index() {
    const ctx = this.ctx;
    const query = {
      project_id: ctx.query.project_id,
    };
    const result = await ctx.model.Tag.findAll({
      where: query
    });
    this.success(result);
  }

  async show() {
    const ctx = this.ctx;
    const result = await ctx.model.Tag.findByPk(toInt(ctx.params.id));
    this.success(result);
  }

  async create() {
    const ctx = this.ctx;
    console.log(ctx.request.body);
    if (!ctx.request.body.tag_name || !ctx.request.body.project_id) {
      this.fail('请完善必填项！');
      return;
    }
    const tag = await ctx.model.Tag.create(ctx.request.body);
    this.success(tag);
  }

  async update() {
    const ctx = this.ctx;
    const id = toInt(ctx.params.id);
    const tag = await ctx.model.Tag.findByPk(id);
    if (!tag) {
      ctx.status = 404;
      ctx.body = {
        code: 1,
        success: false,
        msg: '库里没有该条数据',
      };
      return;
    }
    await tag.update(ctx.request.body);
    this.success(tag);
  }

  async destroy() {
    const ctx = this.ctx;
    const id = toInt(ctx.params.id);
    const tag = await ctx.model.Tag.findByPk(id);
    if (!tag) {
      ctx.status = 404;
      ctx.body = {
        code: 1,
        success: false,
        msg: '库里没有该条数据',
      };
      return;
    }

    await tag.destroy();
    this.success({
      data: '已删除',
    });
  }
}

module.exports = TagController;
